@@ -358,7 +358,7 @@ help_cb (GtkAction *action, GtkWidget *callback_data)
                                                                                 
         if (error != NULL) {
                 gconf_editor_window_popup_error_dialog (GTK_WINDOW (GCONF_EDITOR_WINDOW (callback_data)),
-                                                        _("Couldn't display help: %s"), error->message);
+                                                        _("Couldn't display help: %s"), error);
         }
 }
 
@@ -392,7 +392,7 @@ gconf_editor_window_about_window (GtkAction *action, GtkWidget *callback_data)
 		"Shaun McCance <shaunm@gnome.org>",
 		NULL
 	};
-	const gchar *translator_credits = _("translator_credits");
+	const gchar *translator_credits = _("translator-credits");
 
 	gtk_show_about_dialog (GTK_WINDOW (callback_data),
 			      "version", VERSION,
@@ -400,7 +400,7 @@ gconf_editor_window_about_window (GtkAction *action, GtkWidget *callback_data)
 			      "comments", _("An editor for the GConf configuration system."),
 			      "authors", authors,
 			      "documenters", documenters,
-			      "translator_credits", strcmp(translator_credits, "translator_credits") != 0 ? translator_credits : NULL,
+			      "translator_credits", strcmp(translator_credits, "translator-credits") != 0 ? translator_credits : NULL,
 			      "logo_icon_name", "gconf-editor",
 			      NULL);
 }	
@@ -838,10 +838,10 @@ gconf_editor_window_selection_changed (GtkTreeSelection *selection, GConfEditorW
 
 	switch (window->type) {
 	case GCONF_EDITOR_WINDOW_TYPE_DEFAULTS:
-		base_title = _("Configuration Editor (Default Settings)");
+		base_title = _("Configuration Editor (Default settings)");
 		break;
 	case GCONF_EDITOR_WINDOW_TYPE_MANDATORY:
-		base_title = _("Configuration Editor (Mandatory Settings)");
+		base_title = _("Configuration Editor (Mandatory settings)");
 		break;
 	default:
 		base_title = _("Configuration Editor");
